/*
* Ultrasonic Sensor HC-SR04 detect distance to object
* 
* this code uses it in order to discover 
* if someone passed in front of the sensor
*
*/
// defines pins numbers
const int trigPin = 9;
const int echoPin = 10;

// defines variables
long duration;
int distance;
int max_dist=60; // cm
int alert_dist=50; // cm

#define DIST_FAR    1
#define DIST_NEAR   2

byte currect_dist_state;

void setup_dist() {
  pinMode(trigPin, OUTPUT); // Sets the trigPin as an Output
  pinMode(echoPin, INPUT); // Sets the echoPin as an Input

  currect_dist_state=DIST_FAR;
}

float maxLenInMicroSec=max_dist * 2 / 0.034; // max time we wait for responses. this calculation is for max_dist cm
bool loop_dist() {
  bool ret=false;

calc_dist();
debug("dist=");
debugln(String(distance));

  /*
   * the following code will give one true for a whole pass
   * the true is at the END of the pass
   */
  if((distance==0)||(distance > alert_dist)){ // no detection
    if(currect_dist_state == DIST_NEAR){ // new detection
      currect_dist_state=DIST_FAR;
      ret=true;
    }
  }
  else { // now detecting
    currect_dist_state=DIST_NEAR;    
  }
  return ret;
}
void calc_dist(){
  sendTrig();
  // Reads the echoPin, returns the sound wave travel time in microseconds
  duration = pulseIn(echoPin, HIGH,maxLenInMicroSec);
  // Calculating the distance
  distance= round(duration*0.034/2);  
}
void sendTrig(){
    // Clears the trigPin
  digitalWrite(trigPin, LOW);
  delayMicroseconds(2);
  // Sets the trigPin on HIGH state for 10 micro seconds
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW);
}

