/*
 * This project creates a detector for entering the room
 * It displays how many times people entered the room
 * Has the ability to reset counting
 * And has a code protection on that reset (so the visitor won't reset)
 *  
 *  Display is a 7 Segment element with shift registers
 *  Code input is 2 push buttons
 *   
 *   enjoy
 *   www.Kits4.Me
 */


#define SYS_STT_WAKING  1
#define SYS_STT_READY   2
#define SYS_STT_ENTERED 3

 byte currState = SYS_STT_WAKING;

int entered_times=0;
bool IamIn=true;

void setup() {
  debugStart();
  setup_7seg ();
  setup_stateMngr();
  setup_kodan();
  setup_dist();
}
unsigned long curr_time;
unsigned long last_check_time=0;

void loop() {
  loop_stateMngr();
  if(currState == SYS_STT_WAKING){
    displayOFF();
  } else {
    showDigits(entered_times);
    curr_time=millis();
    if(curr_time - last_check_time > 500){
      last_check_time=curr_time;
      if(loop_dist()) {
        inc_count();
      }
      if(!IamIn && (loop_motion())){
        inc_count();
      }
    }
  }
  if(loop_kodan()){
    reset_count();
  }
}
void inc_count(){
  if(IamIn){
    IamIn=false;
  }
  else {
    entered_times++;
    currState = SYS_STT_ENTERED;
  }
  debug("entered_times=");
  debugln(String(entered_times));
}
void reset_count(){
  debugln("reset_count");
  
  //seting counter to 0 and showing green light
  entered_times=0;
  currState = SYS_STT_READY;
  IamIn=true;
}

